==> haskell-network-ip-0.3.0.2-85-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-4PBOsqN4Z8P1ambalyuWNO
key: network-ip-0.3.0.2-4PBOsqN4Z8P1ambalyuWNO
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 512e9c795a8841aa75b104b43ffbd5b0
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-4PBOsqN4Z8P1ambalyuWNO
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.2-3VimIP7Kqe02FhIqdRkzuM
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-3946i3cs4hq2o8nhRd9kpm
    data-textual-0.3.0.2-F2xZ0NlqzrN6gmTZCqPW34
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.9-EBQu33tsh371uZhmDNohVJ
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.2-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-LRKTQf8Gwut1uaXcB1iFyS
key: network-ip-0.3.0.2-LRKTQf8Gwut1uaXcB1iFyS
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 5ea7295d2df97f533933236e31b07f30
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-LRKTQf8Gwut1uaXcB1iFyS
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.2-IecX8ZMFNUI96BJXkkV54h
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-Jo2KtZqZGibHtFQqyP4PRY
    data-textual-0.3.0.2-G0axfmqYjagGN7YILsePIN
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.9-AVnyzZUtkE6FvW7jmwu5Z1
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
